@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2017 Cppcheck team.
+ * Copyright (C) 2007-2018 Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,6 +56,10 @@ public:
         mAddonsAndTools = addonsAndTools;
     }
 
+    void setMisraFile(const QString &misraFile) {
+        mMisraFile = misraFile;
+    }
+
     void setDataDir(const QString &dataDir) {
         mDataDir = dataDir;
     }
@@ -148,6 +152,7 @@ private:
     QString mDataDir;
     QStringList mClangIncludePaths;
     QStringList mSuppressions;
+    QString mMisraFile;
 };
 /// @}
 #endif // CHECKTHREAD_H
